=======
Credits
=======

Development Lead
----------------

* Samuel Murail, Université de Paris <samuel.murail@u-paris.fr>

Contributors
------------

* Maxence Delaunay
* Damien Espana

We are open to any contribution.
